@@ -1,8 +1,8 @@
-from .reg.numbers import re_num_list
-from .reg.numberscales import re_number_scale_list
-from .reg.date import re_date_list
-from .reg.id import re_id_list
-from .reg.oov import format_word, vi_dict
+from .renumbers import re_num_list
+from .renumberscales import re_number_scale_list
+from .redate import re_date_list
+from .reid import re_id_list
+from .reoov import format_word, vi_dict
 import re
 from nltk import word_tokenize
 import nltk
